@@ -3,7 +3,7 @@
 """
 The main window of krop
 
-Copyright (C) 2010-2020 Armin Straub, http://arminstraub.com
+Copyright (C) 2010-2025 Armin Straub, http://arminstraub.com
 """
 
 """
@@ -15,31 +15,15 @@ the Free Software Foundation; either version 3 of the License, or
 
 import sys
 from os.path import exists, splitext
-
-try:
-    from shutil import which
-except:
-    # shutil is not available in python2; instead we use the following:
-    from distutils.spawn import find_executable as which
-
-try:
-    str_unicode = unicode
-except:
-    str_unicode = str
-
+from shutil import which
 
 from krop.qt import *
-from krop.config import PYQT5, KDE
+from krop.config import PYQT6
 
-if KDE:
-    from PyKDE4.kdeui import KMainWindow as QKMainWindow
+if PYQT6:
+    from krop.mainwindowui_qt6 import Ui_MainWindow
 else:
-    QKMainWindow = QMainWindow
-
-if PYQT5:
     from krop.mainwindowui_qt5 import Ui_MainWindow
-else:
-    from krop.mainwindowui_qt4 import Ui_MainWindow
 
 from krop.viewerselections import ViewerSelections, aspectRatioFromStr
 from krop.vieweritem import ViewerItem
@@ -133,12 +117,12 @@ class DeviceTypeManager(AspectRatioTypeManager):
         self.addType("Nook 1st Ed. (widescreen)", 730, 600)
 
 
-class MainWindow(QKMainWindow):
+class MainWindow(QMainWindow):
 
     fileName = None
 
     def __init__(self):
-        QKMainWindow.__init__(self)
+        QMainWindow.__init__(self)
 
         self.selAspectRatioTypes = SelAspectRatioTypeManager()
         self.deviceTypes = DeviceTypeManager()
@@ -335,7 +319,7 @@ class MainWindow(QKMainWindow):
             self.viewer.load(fileName)
             if not self.viewer.isEmpty():
                 self.fileName = fileName
-                outputFileName = "%s-cropped.pdf" % splitext(str_unicode(fileName))[0]
+                outputFileName = "%s-cropped.pdf" % splitext(fileName)[0]
                 self.slotFitInView(self.ui.actionFitInView.isChecked())
             else:
                 self.fileName = ''
@@ -343,6 +327,7 @@ class MainWindow(QKMainWindow):
                 self.showWarning(self.tr("Something got in our way"),
                         self.tr("The PDF file couldn't be read. "
                             "Please check the file and its permissions."))
+            self.setWindowFilePath(self.fileName)
             self.ui.actionKrop.setEnabled(not self.viewer.isEmpty())
             self.ui.actionTrimMarginsAll.setEnabled(not self.viewer.isEmpty())
             self.ui.editFile.setText(outputFileName)
@@ -351,10 +336,7 @@ class MainWindow(QKMainWindow):
     def slotOpenFile(self):
         fileName = QFileDialog.getOpenFileName(self,
              self.tr("Open PDF"), "", self.tr("PDF Files (*.pdf)"));
-        # in PyQt5, getOpenFileName is what used to be
-        # getOpenFileNameAndFilter
-        if PYQT5:
-            fileName = fileName[0]
+        fileName = fileName[0]
         self.openFile(fileName)
 
     def slotSelectFile(self):
@@ -388,11 +370,11 @@ class MainWindow(QKMainWindow):
 
     def slotKrop(self):
         # file names
-        inputFileName = str_unicode(self.fileName)
-        outputFileName = str_unicode(self.ui.editFile.text())
+        inputFileName = self.fileName
+        outputFileName = self.ui.editFile.text()
 
         # which pages
-        s = str(self.ui.editWhichPages.text())
+        s = self.ui.editWhichPages.text()
         if not s:
             pages = range(self.viewer.numPages())
         else:
@@ -408,11 +390,12 @@ class MainWindow(QKMainWindow):
         #             self.tr("A file named \"...\" already exists. Are you sure you want to overwrite it?"))
         #     return
 
-        QApplication.setOverrideCursor(Qt.WaitCursor)
+        QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
         try:
             pdf = PdfFile()
             pdf.loadFromFile(inputFileName)
             cropper = PdfCropper()
+            cropper.copyDocumentRoot(pdf)
             for nr in pages:
                 c = self.viewer.cropValues(nr)
                 cropper.addPageCropped(pdf, nr, c, alwaysinclude, rotation)
@@ -460,7 +443,7 @@ class MainWindow(QKMainWindow):
     def slotFitInView(self, checked):
         if checked:
             self.ui.documentView.fitInView(self.pdfScene.sceneRect(),
-                    Qt.KeepAspectRatio)
+                    Qt.AspectRatioMode.KeepAspectRatio)
 
     def slotSplitterMoved(self, pos, idx):
         self.slotFitInView(self.ui.actionFitInView.isChecked())
@@ -511,13 +494,13 @@ class MainWindow(QKMainWindow):
             self.ui.editSelExceptions.setEnabled(enableExceptions)
 
     def slotSelExceptionsChanged(self):
-        s = str(self.ui.editSelExceptions.text())
+        s = self.ui.editSelExceptions.text()
         pages = self.str2pages(s)
         self.selections.selectionExceptions = pages
 
     def slotSelExceptionsEdited(self, text):
         try:
-            pages = self.str2pages(str(text))
+            pages = self.str2pages(text)
             self.selections.selectionExceptions = pages
         except ValueError:
             pass
@@ -694,7 +677,7 @@ class MainWindow(QKMainWindow):
         if self.ui.checkTrimUseAllPages.isChecked():
             pages = [i for i in range(self.viewer.numPages()) if sel.selectionVisibleOnPage(i)]
 
-        QApplication.setOverrideCursor(Qt.WaitCursor)
+        QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
         try:
             # orect is the original selection, nrect is the trimmed version
             orect = sel.mapRectToImage(sel.rect).toRect()
